/**
 * Enhanced Match Analysis JavaScript with mobile support
 * Path: assets/js/analysis.js
 */

document.addEventListener('DOMContentLoaded', function() {
    // Handle league selection change - reload teams
    const leagueSelect = document.getElementById('league');
    const homeSelect = document.getElementById('home');
    const awaySelect = document.getElementById('away');
    const analysisForm = document.getElementById('analysisForm');
    
    if (leagueSelect && homeSelect && awaySelect) {
        leagueSelect.addEventListener('change', function() {
            // Submit form with only league parameter to reload teams
            const league = leagueSelect.value;
            window.location.href = `match-analysis.php?league=${league}`;
        });
        
        // Prevent selecting the same team for home and away
        function validateTeamSelection() {
            const homeTeamId = homeSelect.value;
            const awayTeamId = awaySelect.value;
            
            if (homeTeamId && awayTeamId && homeTeamId === awayTeamId) {
                alert('Home and away teams cannot be the same. Please select different teams.');
                return false;
            }
            
            return true;
        }
        
        analysisForm.addEventListener('submit', function(event) {
            if (!validateTeamSelection()) {
                event.preventDefault();
            }
        });
        
        // Add validation on team selection change
        homeSelect.addEventListener('change', validateTeamSelection);
        awaySelect.addEventListener('change', validateTeamSelection);
    }
    
    // Collapsible sections
    const collapsibleHeaders = document.querySelectorAll('.collapsible-header');
    
    collapsibleHeaders.forEach(header => {
        // Open first section by default
        if (header === collapsibleHeaders[0]) {
            header.classList.add('active');
            const content = document.getElementById(header.getAttribute('data-target'));
            if (content) {
                content.classList.add('active');
                content.style.maxHeight = content.scrollHeight + 'px';
            }
        }
        
        header.addEventListener('click', function() {
            this.classList.toggle('active');
            const target = this.getAttribute('data-target');
            const content = document.getElementById(target);
            
            if (content) {
                content.classList.toggle('active');
                
                if (content.classList.contains('active')) {
                    content.style.maxHeight = content.scrollHeight + 'px';
                } else {
                    content.style.maxHeight = 0;
                }
            }
        });
    });
    
    // Accordion sections
    const accordionHeaders = document.querySelectorAll('.accordion-header');
    
    accordionHeaders.forEach(header => {
        header.addEventListener('click', function() {
            this.classList.toggle('active');
            const target = this.getAttribute('data-target');
            const content = document.getElementById(target);
            
            if (content) {
                content.classList.toggle('active');
                
                if (content.classList.contains('active')) {
                    content.style.maxHeight = content.scrollHeight + 'px';
                } else {
                    content.style.maxHeight = 0;
                }
            }
        });
    });
    
    // Mobile tabs
    const tabButtons = document.querySelectorAll('.tab-btn');
    const tabPanes = document.querySelectorAll('.tab-pane');
    
    tabButtons.forEach(button => {
        button.addEventListener('click', function() {
            // Remove active class from all buttons
            tabButtons.forEach(btn => {
                btn.classList.remove('active');
            });
            
            // Hide all tab panes
            tabPanes.forEach(pane => {
                pane.classList.remove('active');
            });
            
            // Set clicked button as active
            this.classList.add('active');
            
            // Show corresponding tab pane
            const tabId = this.getAttribute('data-tab');
            const tabPane = document.getElementById(tabId + '-tab');
            if (tabPane) {
                tabPane.classList.add('active');
            }
        });
    });
    
    // Add smooth scrolling to analysis section after form submission
    const analysisSection = document.querySelector('.analysis-section');
    if (analysisSection) {
        window.scrollTo({
            top: analysisSection.offsetTop - 80,
            behavior: 'smooth'
        });
    }
    
    // Auto-adjust collapsible content heights when window is resized
    window.addEventListener('resize', function() {
        const activeCollapsible = document.querySelectorAll('.collapsible-content.active, .accordion-content.active');
        
        activeCollapsible.forEach(content => {
            content.style.maxHeight = 'none'; // Temporarily remove max-height to get actual height
            content.style.maxHeight = content.scrollHeight + 'px';
        });
    });
});