<?php
/**
 * Create database tables
 * Path: setup/create_tables.php
 * 
 * Run this file once to create the database tables
 */

require_once '../includes/db.php';

// SQL to create users table
$sql_users = "CREATE TABLE IF NOT EXISTS users (
    id INT(11) NOT NULL AUTO_INCREMENT PRIMARY KEY,
    username VARCHAR(50) NOT NULL UNIQUE,
    email VARCHAR(100) NOT NULL UNIQUE,
    password VARCHAR(255) NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;";

// SQL to create saved_predictions table
$sql_predictions = "CREATE TABLE IF NOT EXISTS saved_predictions (
    id INT(11) NOT NULL AUTO_INCREMENT PRIMARY KEY,
    user_id INT(11) NOT NULL,
    home_team_id INT(11) NOT NULL,
    away_team_id INT(11) NOT NULL,
    match_date DATETIME NOT NULL,
    prediction_data JSON NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (user_id) REFERENCES users(id) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;";

// SQL to create bet_history table
$sql_bet_history = "CREATE TABLE IF NOT EXISTS bet_history (
    id INT(11) NOT NULL AUTO_INCREMENT PRIMARY KEY,
    user_id INT(11) NOT NULL,
    home_team_id INT(11) NOT NULL,
    away_team_id INT(11) NOT NULL,
    bet_type VARCHAR(50) NOT NULL,
    stake DECIMAL(10,2) NOT NULL,
    odds DECIMAL(10,2) NOT NULL,
    result ENUM('win', 'loss', 'pending') DEFAULT 'pending',
    profit_loss DECIMAL(10,2) DEFAULT 0,
    match_date DATETIME NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (user_id) REFERENCES users(id) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;";

// Execute queries
if ($conn->query($sql_users) === TRUE) {
    echo "Table 'users' created successfully<br>";
} else {
    echo "Error creating 'users' table: " . $conn->error . "<br>";
}

if ($conn->query($sql_predictions) === TRUE) {
    echo "Table 'saved_predictions' created successfully<br>";
} else {
    echo "Error creating 'saved_predictions' table: " . $conn->error . "<br>";
}

if ($conn->query($sql_bet_history) === TRUE) {
    echo "Table 'bet_history' created successfully<br>";
} else {
    echo "Error creating 'bet_history' table: " . $conn->error . "<br>";
}

$conn->close();

echo "<p>Database setup complete. You can now <a href='../index.php'>go to the login page</a>.</p>";
?>